==> sddm_0.11.0.orig.tar.gz: sddm-0.11.0/data/translations/ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>ようこそ %1 へ</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>注意: Caps ロックがオンになっています!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>キーボード</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>ログイン</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>ログイン失敗</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>ログイン成功</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>ユーザ名とパスワードを入力してください</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>セッション</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>ユーザ名</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>ユーザ名を選び、パスワードを入力してください</translation>
    </message>
</context>
</TS>

==> sddm_0.19.0.orig.tar.gz: sddm-0.19.0/data/translations/ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>ようこそ %1 へ</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>注意: Caps ロックがオンになっています!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>キーボード</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>ログイン</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>ログイン失敗</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>ログイン成功</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>ユーザ名とパスワードを入力してください</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>セッション</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>ユーザ名</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>ユーザ名を選び、パスワードを入力してください</translation>
    </message>
</context>
</TS>
